# Code-Viewer
This app serves to display XML or (X)HTML code with syntax highlighting on a website.
It is fully compatible with any CSS themes provided by [highlight.js](https://highlightjs.org/) but without the client-sided JavaScript rendering that leads to performance losses while displaying large files.

Its main purposes are to

1. remove the dependency on JavaScript and by that providing more security
2. take load away from the client and let the server do all the work

This module has originally been developed for the DFG-funded project [Bibliothek der Neologie](https://www.bdn-edition.de) and spun off as a generic app for [SADE](https://gitlab.gwdg.de/SADE).

## Usage

To use the package simply include it in your XQuery via import with

```
import module namespace code-view="http://bdn-edition.de/ns/code-view";
```

This module provides options for a **basic** and **extended** mode.

### Basic mode

The basic mode offers you

* the highlighted code in an `xhtml:pre` element
* full compatibility with [highlight.js](https://highlightjs.org/)'s CSS
* display of comments

Simply call

```
code-view:main($nodes as node()+)
```

with `$nodes` being the XML nodes you want to render.



### Extended mode

The extended mode offers you

* the highlighted code in an `xhtml:pre` element
* the option to decide on whether you want comments to be displayed or not
* full compatibility with [highlight.js](https://highlightjs.org/)'s CSS **OR** a custom prefix for other CSS classes


Simply call

```
code-view:main($nodes as node()+, $comments as xs:boolean?, $prefix as xs:string?)
```

In case you pass an empty string to `$prefix` it defaults to `hljs-` which is the prefix compatible with [highlight.js](https://highlightjs.org/).


## Sample output

To see the Code Viewer in action we encourage you to visit the code view of [Theodor Fontane's notebook C7](https://fontane-nb.dariah.eu/xml.html?id=/xml/data/16b00.xml) which uses the [Visual Studio style](https://github.com/highlightjs/highlight.js/blob/master/src/styles/vs.css) of [highlight.js](https://highlightjs.org/).


## Contributing

Feel free to contribute to this repo by sending us a pull request! Please make sure you stick to the [RDD style guides](https://github.com/subugoe/rdd-technical-reference/blob/master/rdd-technical-reference.md) for XQuery.

## License

See  the [LICENSE](https://gitlab.gwdg.de/SADE/SADE/blob/develop/LICENSE) file.
